
package action;

import java.text.SimpleDateFormat;
import java.util.Collection;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.Action;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.hibernate.JDBCException;

import hibernate.Perfil;
import hibernate.PerfilDAO;
import hibernate.Usuario;
import hibernate.UsuarioDAO;
import hibernate.Persona;
import hibernate.PersonaDAO;
import hibernate.Localidad;
import hibernate.LocalidadDAO;
import form.MiUsuarioForm;

public class PreparaEditarMiUsuarioAction extends Action {

	private static Log log = LogFactory.getLog(PreparaEditarMiUsuarioAction.class);


	public ActionForward execute(ActionMapping mapping, ActionForm form,
			HttpServletRequest request, HttpServletResponse response) {

		// Gerrores
		ActionErrors errores = new ActionErrors();
		MiUsuarioForm formUsuario = (MiUsuarioForm) form;
		formUsuario.clean(mapping, request);
		
		// Usuario
		HttpSession session = request.getSession(false);
		Usuario u = new Usuario();
		if (session != null && session.getAttribute("usuario") != null) {
			u = (Usuario)session.getAttribute("usuario");
			formUsuario.setId(u.getId());
			log.debug("El usuario editado es " + u.getLogin());
		}
		
		// Perfil y Localidad
		LocalidadDAO locDAO = new LocalidadDAO();
		PerfilDAO perfilDAO = new PerfilDAO();
		
		// Cargamos elementos
		Collection<Perfil> listaPerfiles = perfilDAO.findAll();
		Collection<Localidad> listaLocalidades = locDAO.findAll();
		
		request.getSession().setAttribute("listadoPerfiles", listaPerfiles);
		request.getSession().setAttribute("listadoLocalidades",
				listaLocalidades);

		UsuarioDAO userDAO = new UsuarioDAO();
		Usuario user = null;

		Persona persona = null;
		PersonaDAO personaDAO = new PersonaDAO();

		try {
			if (u.getId() != null) {
				// usuario seleccionado
				int idUsuario = Integer.parseInt(u.getId().toString());
				user = userDAO.findById(idUsuario);
				if (user == null) {
					log.error(" El usuario no existe ");
					errores.add("errores", new ActionMessage(
							"usuario.error.editar.usuarionoexiste"));
					this.saveErrors(request, errores);
					return mapping.findForward("fail");
				} else {
					persona = personaDAO.findById(user.getPersona().getId());
					
					// Comprobamos que el usuario no este borrado
					if (user.getPersona().getFechaBaja() != null) {
						log.error("El usuario esta borrado");
						errores.add("errores", new ActionMessage(
								"usuario.error.editar.usuarionoexiste"));
						this.saveErrors(request, errores);
						return mapping.findForward("fail");
					}

					// Persona
					formUsuario.setNombre(persona.getNombre());
					formUsuario.setId(user.getId());
					formUsuario.setApellido1(persona.getApellido1());
					formUsuario.setApellido2(persona.getApellido2());
					formUsuario.setDni(persona.getDni());
					if (persona.getLocalidad() != null)
						formUsuario.setLocalidad(persona.getLocalidad().getId()
							.toString());

					if (persona.getFechaNacimiento() != null) {
						// Preparamos la fecha en el formato "dd/MM/yyyy"
						SimpleDateFormat sdf = new SimpleDateFormat("dd/MM/yyyy");
						formUsuario.setFecha_nacimiento(sdf.format(persona.getFechaNacimiento()));
					}
					formUsuario.setDireccion(persona.getDireccion());
					formUsuario.setTelefono(persona.getTelefono());
					formUsuario.setMovil(persona.getMovil());
					formUsuario.setEmail(persona.getEmail());
					formUsuario.setCodigo_postal(persona.getCodigoPostal());

					// Usuario
					formUsuario.setUsuario(user.getLogin());
					formUsuario.setClave1(null);
					formUsuario.setClave2(formUsuario.getClave1());
					formUsuario.setPerfil(user.getPerfil().getId()
							.toString());
				}
			}
			return mapping.findForward("success");
		} catch (JDBCException e) {
			throw e;
		} catch (Exception e) {
			e.printStackTrace();
			log.error("Error cargando los datos");
			// Guardamos el error
			errores.add("errores", new ActionMessage(
					"usuario.error.editar.usuarionoexiste"));
			this.saveErrors(request, errores);
			return mapping.findForward("fail");
		}
	}

}