package action;

import java.io.IOException;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.tiles.TilesRequestProcessor;

import hibernate.Usuario;
import hibernate.UsuarioDAO;
import util.ConstantesProyecto;

public class SecurityRequestProcessor extends TilesRequestProcessor {

	private static Log logs = LogFactory
			.getLog(SecurityRequestProcessor.class);
	// Enlaces permitidos sin loggin
	private static String forwardLogin = "/login.do";
	private static String forwardLogon = "/logon.do";
	private static String forwardpreparaNuevoVoluntarioExterno = "/preparaNuevoVoluntarioExterno.do";
	private static String forwardNuevoVoluntarioExterno = "/nuevoVoluntarioExterno.do";
	private static String forwardpreparaRecordarClave = "/preparaRecordarClave.do";
	private static String forwardRecordarClave = "/recordarClave.do";
	private static String forwardpreparaNuevaAsociacionExterno = "/preparaNuevaAsociacionExterno.do";
	private static String forwardNuevaAsociacionExterno = "/nuevaAsociacionExterno.do";
	public static String GLOBAL_ROL_ADMINISTRADOR = "Administrador";
	

	@Override
	protected boolean processPreprocess(HttpServletRequest request,
			HttpServletResponse response) {
		
		HttpSession session = request.getSession(false);
		// If user is trying to access login page
		// then don't check
		logs.debug("Comprobamos donde va: " + request.getServletPath());
		if (request.getServletPath().equals(forwardLogin)
				|| request.getServletPath().equals(forwardLogon)
				|| request.getServletPath().equals(forwardpreparaNuevoVoluntarioExterno)
				|| request.getServletPath().equals(forwardNuevoVoluntarioExterno)
				|| request.getServletPath().equals(forwardpreparaNuevaAsociacionExterno)
				|| request.getServletPath().equals(forwardNuevaAsociacionExterno)
				|| request.getServletPath().equals(forwardpreparaRecordarClave)
				|| request.getServletPath().equals(forwardRecordarClave)) 
		{
			logs.debug("No se realiza ninguna accion");
			return true;
		}
		// Check if userName attribute is there is session.
		// If so, it means user has already logged in
		if (session != null && session.getAttribute("usuario") != null) {
			logs.debug("Usuario autentificado");
			return true;
		} else {
			try {
				// If no redirect user to login Page
				logs.debug("El usuario no esta autentificado");
				logs
						.info("Zona Restringida: Redirigimos el usuario al formulario de autentificacion");
				request.getRequestDispatcher(forwardLogin).forward(request,
						response);
			} catch (Exception ex) {
				logs.error("Se ha producido un error al redireccionar");
				ex.printStackTrace();
				return false;
			}
		}
		
		return true;
	}
	

	@Override
	protected boolean processRoles(HttpServletRequest request,
			HttpServletResponse response, ActionMapping mapping)
			throws IOException, ServletException {
		
		try {
		// roles
		String roles[] = mapping.getRoleNames();
		// Comprobamos que existen roles
		if ((roles == null) || (roles.length < 1)) {
			logs.debug("No existen roles para " + request.getServletPath());
			return true;
		}
		// Recuperamos la sesion para comprobar si hay alguien autentificado
		if (request.getSession().getAttribute("usuario") == null) {
			logs.debug("No existe el usuario");
			return false;
		}
		// Instanciamos el usuario
		UsuarioDAO usuarioDAO = new UsuarioDAO();
		Usuario usuario = null;
		if (request.getSession().getAttribute("usuario") instanceof Usuario) {
			usuario = (Usuario)request.getSession().getAttribute("usuario");
		} else {
			logs.error("El usuario guardado en la sesion no es del tipo correcto");
			return false;
		}
				
		// Comprobamos que el usuario tenga permisos
		if ((usuario.getPerfil() != null) && (!usuario.getPerfil().getNombre().equals(
				""))) {
			// Recorremos los roles de la accion
			for (int i = 0; i < roles.length; i++) {
				// Comprobamos que tenga el rol correcto
				if (roles[i].equals(usuario.getPerfil().getNombre())) {
					if (log.isDebugEnabled())
						logs.debug("Usuario con Permisos");
					// Dejamos entrar
					return true;
				}
			}
			// Si es para confirmar un borrado
			if (request.getServletPath().equals("/confirmar.do")) {
				// Obtenemos el tipo de borrado
				String strIdConfirmacion = request
						.getParameter("Id_Confirmacion");
				if ((Integer.parseInt(strIdConfirmacion) == ConstantesProyecto.GLOBAL_CONFIRMAR_USUARIO) ||
						(Integer.parseInt(strIdConfirmacion) == ConstantesProyecto.GLOBAL_CONFIRMAR_ASO)) {
					// Si el usuario es administrador le damos permiso
					return true;
				}
			}
				
		} 
		
		response.sendError(HttpServletResponse.SC_FORBIDDEN,getInternal().getMessage("notAuthorized",mapping.getPath()));
		return false;
			
		} catch (Exception e) {
			e.printStackTrace();
			logs.error(e.getMessage());
			return false;
		}
	}
		
}