package graficas;

import java.math.BigInteger;

import org.hibernate.Query;
import org.hibernate.Session;

import hibernate.HibernateSessionFactory;


public class GraficaUsuariosDiscapacitados extends Grafica {

	// eje de ordenadas
	public static final String[] LABELS_EDAD = { "- 30 años", "30/40 años",
			"40/50 años", "+ 50 años" };
	public static final String[] LABELS_SEXO = { "Hombre", "Mujeres" };
	
	// Titulo
	public static final String TITLE_DISCAPACIDAD = "Usuarios con Discapacidad";
	public static final String TITLE_NO_DISCAPACIDAD = "Usuarios sin Discapacidad";

	// Sentencias sql
	private static final String SQL_TOTAL_PD = "SELECT count(*) from persona_dependiente where fec_baja_beneficiario is null";
	private static final String SQL_TOTAL_PD_DISCAPACITADOS = "SELECT count(*) from persona_dependiente WHERE ((discapacidad is null) or (discapacidad <= 0)) and (fec_baja_beneficiario is null)";
	private static final String SQL_TOTAL_PD_NO_DISCAPACITADOS = "SELECT count(*) from persona_dependiente WHERE ((discapacidad is not null) and (discapacidad > 0)) and (fec_baja_beneficiario is null)";

	private static final String SQL_TOTAL_PD_TOTAL = "SELECT count(*) FROM persona_dependiente pd "
		+ " JOIN persona per ON per.id = pd.id_persona"
		+ " WHERE fecha_nacimiento IS NOT NULL"
		+ " AND fec_baja_beneficiario IS NULL"
		;
	private static final String SQL_TOTAL_PD_LT30 = "SELECT count(*) FROM persona_dependiente pd "
			+ " JOIN persona per ON per.id=pd.id_persona"
			+ " WHERE fecha_nacimiento IS NOT NULL"
			+ " AND ((EXTRACT(year from current_date)) - (EXTRACT(year from fecha_nacimiento))) < 30" // AGE(fecha_nacimiento) < 30"
			+ " AND fec_baja_beneficiario IS NULL"
			+ " AND ((discapacidad is not null) AND (discapacidad > 0))";
	private static final String SQL_TOTAL_PD_B30_40 = "SELECT count(*) FROM persona_dependiente pd "
			+ " JOIN persona per ON per.id=pd.id_persona"
			+ " WHERE fecha_nacimiento IS NOT NULL"
			+ " AND ((EXTRACT(year from current_date)) - (EXTRACT(year from fecha_nacimiento))) >= 30 "// AGE(fecha_nacimiento) >= 30"
			+ " AND ((EXTRACT(year from current_date)) - (EXTRACT(year from fecha_nacimiento))) < 40" //AGE(fecha_nacimiento) < 40"
			+ " AND fec_baja_beneficiario IS NULL"
			+ " AND ((discapacidad is not null) AND (discapacidad > 0))";
	private static final String SQL_TOTAL_PD_B40_50 = "SELECT count(*) FROM persona_dependiente pd "
		+ " JOIN persona per ON per.id=pd.id_persona"
		+ " WHERE fecha_nacimiento IS NOT NULL"
		+ " AND ((EXTRACT(year from current_date)) - (EXTRACT(year from fecha_nacimiento))) >= 40"//AGE(fecha_nacimiento) >= 40"
		+ " AND ((EXTRACT(year from current_date)) - (EXTRACT(year from fecha_nacimiento))) < 50"//AGE(fecha_nacimiento) < 50"
		+ " AND fec_baja_beneficiario IS NULL"
		+ " AND ((discapacidad is not null) AND (discapacidad > 0))";
	private static final String SQL_TOTAL_PD_GT50 = "SELECT count(*) FROM persona_dependiente pd "
		+ " JOIN persona per ON per.id=pd.id_persona"
		+ " WHERE fecha_nacimiento IS NOT NULL"
		+ " AND ((EXTRACT(year from current_date)) - (EXTRACT(year from fecha_nacimiento))) > 50" //AGE(fecha_nacimiento) > 50"
		+ " AND fec_baja_beneficiario IS NULL"
		+ " AND ((discapacidad is not null) AND (discapacidad > 0))";

	
	public double[] getDatosEdad() {

		double[] data = new double[4];

		try {

			Session sesion = HibernateSessionFactory.getSession();
			// Creamos el sql para recuperar todos los PD que tengan fecha de nacimiento
			Query query = sesion.createSQLQuery(SQL_TOTAL_PD_TOTAL);
			// Recupera los datos de la base de datos
			BigInteger totalPD = (BigInteger) query.list().get(0); //.get(0);
			// PD de menos de 30 de edad
			query = sesion.createSQLQuery(SQL_TOTAL_PD_LT30);
			// Recupera los datos de la base de datos
			BigInteger totalPDL30 = (BigInteger) query.list().get(0);
			// PD de entre 30 y 40 de edad
			query = sesion.createSQLQuery(SQL_TOTAL_PD_B30_40);
			// Recupera los datos de la base de datos
			BigInteger totalPDB3040 = (BigInteger) query.list().get(0);
			// PD de menos de 30 de edad
			query = sesion.createSQLQuery(SQL_TOTAL_PD_B40_50);
			// Recupera los datos de la base de datos
			BigInteger totalPDB4050 = (BigInteger) query.list().get(0);
			// PD de menos de 30 de edad
			query = sesion.createSQLQuery(SQL_TOTAL_PD_GT50);
			// Recupera los datos de la base de datos
			BigInteger totalPDG50 = (BigInteger) query.list().get(0);
			
			// Hacemos el calculo de los datos
			data[0] = (totalPDL30.doubleValue() / totalPD.doubleValue()) * 100;
			data[1] = (totalPDB3040.doubleValue() / totalPD.doubleValue()) * 100;
			data[2] = (totalPDB4050.doubleValue() / totalPD.doubleValue()) * 100;
			data[3] = (totalPDG50.doubleValue() / totalPD.doubleValue()) * 100;
			
			// Devolvemos los datos
			return data;

		} catch (Exception e) {
			e.printStackTrace();
			return null;
		}
	}

	
	public double[] getDatosSexo() {

		// Declaracion de Variables
		double[] data = new double[2];

		try {
			// Obtenemos la sesion
			Session sesion = HibernateSessionFactory.getSession();
			// Creamos el sql para recuperar los datos
			Query queryTotales = sesion.createSQLQuery(SQL_TOTAL_PD);
			Query queryDiscapacitados = sesion
					.createSQLQuery(SQL_TOTAL_PD_DISCAPACITADOS);
			Query queryNoDiscapacitados = sesion
			.createSQLQuery(SQL_TOTAL_PD_NO_DISCAPACITADOS);
			// Recupera los datos de la base de datos
			BigInteger totalPD = (BigInteger) queryTotales.list()
					.get(0);
			BigInteger totalPDDiscapacitados = (BigInteger) queryDiscapacitados
					.list().get(0);
			BigInteger totalPDNoDiscapacitados = (BigInteger) queryNoDiscapacitados
			.list().get(0);
			// Hacemos el calculo de los datos
			data[0] = (totalPDDiscapacitados.doubleValue() / totalPD
					.doubleValue()) * 100;
			data[1] = (totalPDNoDiscapacitados
					.doubleValue()) / totalPD.doubleValue() * 100;
			// Devolvemos los datos
			return data;

		} catch (Exception e) {
			e.printStackTrace();
			return null;
		}
	}
}
