package graficas;

import java.math.BigInteger;

import org.hibernate.Query;
import org.hibernate.Session;

import hibernate.HibernateSessionFactory;

public class GraficaUsuariosSexoEdad extends Grafica {

	
	// eje de ordenadas
	public static final String[] LABELS_EDAD = { "- 30 años", "30/40 años",
			"40/50 años", "+ 50 años" };
	public static final String[] LABELS_SEXO = { "Hombre", "Mujeres" };
	
	// Titulo
	public static final String TITLE_EDAD = "Proporción Personas Dependientes por Edad";
	public static final String TITLE_SEXO = "Proporción Personas Dependientes por Sexo";

	// Sentencias sql
	private static final String SQL_TOTAL_PD = "SELECT count(*) from persona_dependiente";
	private static final String SQL_TOTAL_PD_HOMBRES = "SELECT count(*) from persona_dependiente WHERE sexo='H'";

	private static final String SQL_TOTAL_PD_TOTAL = "SELECT count(*) FROM persona_dependiente pd "
		+ " JOIN persona per ON per.id=pd.id_persona"
		+ " WHERE fecha_nacimiento IS NOT NULL";
	private static final String SQL_TOTAL_PD_LT30 = "SELECT count(*) FROM persona_dependiente pd "
			+ " JOIN persona per ON per.id=pd.id_persona"
			+ " WHERE fecha_nacimiento IS NOT NULL"
			+ " AND ((EXTRACT(year from current_date)) - (EXTRACT(year from fecha_nacimiento))) < 30";
	private static final String SQL_TOTAL_PD_B30_40 = "SELECT count(*) FROM persona_dependiente pd "
			+ " JOIN persona per ON per.id=pd.id_persona"
			+ " WHERE fecha_nacimiento IS NOT NULL"
			+ " AND ((EXTRACT(year from current_date)) - (EXTRACT(year from fecha_nacimiento))) >= 30 "
			+ " AND ((EXTRACT(year from current_date)) - (EXTRACT(year from fecha_nacimiento))) < 40";
	private static final String SQL_TOTAL_PD_B40_50 = "SELECT count(*) FROM persona_dependiente pd "
		+ " JOIN persona per ON per.id=pd.id_persona"
		+ " WHERE fecha_nacimiento IS NOT NULL"
		+ " AND ((EXTRACT(year from current_date)) - (EXTRACT(year from fecha_nacimiento))) >= 40"
		+ " AND ((EXTRACT(year from current_date)) - (EXTRACT(year from fecha_nacimiento))) < 50";
	private static final String SQL_TOTAL_PD_GT50 = "SELECT count(*) FROM persona_dependiente pd "
		+ " JOIN persona per ON per.id=pd.id_persona"
		+ " WHERE fecha_nacimiento IS NOT NULL"
		+ " AND ((EXTRACT(year from current_date)) - (EXTRACT(year from fecha_nacimiento))) > 50";

	public double[] getDatosEdad() {

		double[] data = new double[4];

		try {


			Session sesion = HibernateSessionFactory.getSession();
			// sql para recuperar todos los PD que tengan fecha de nacimiento
			Query query = sesion.createSQLQuery(SQL_TOTAL_PD_TOTAL);
			// Recupera los datos de la base de datos
			BigInteger totalPD = (BigInteger) query.list().get(0);
			// PD de menos de 30 de edad
			query = sesion.createSQLQuery(SQL_TOTAL_PD_LT30);
			// Recupera los datos de la base de datos
			BigInteger totalPDL30 = (BigInteger) query.list().get(0);
			// PD de entre 30 y 40 de edad
			query = sesion.createSQLQuery(SQL_TOTAL_PD_B30_40);
			// Recupera los datos de la base de datos
			BigInteger totalPDB3040 = (BigInteger) query.list().get(0);
			// PD de menos de 30 de edad
			query = sesion.createSQLQuery(SQL_TOTAL_PD_B40_50);
			// Recupera los datos de la base de datos
			BigInteger totalPDB4050 = (BigInteger) query.list().get(0);
			// PD de menos de 30 de edad
			query = sesion.createSQLQuery(SQL_TOTAL_PD_GT50);
			// Recupera los datos de la base de datos
			BigInteger totalPDG50 = (BigInteger) query.list().get(0);
			
			// calculo de los datos
			data[0] = (totalPDL30.doubleValue() / totalPD.doubleValue()) * 100;
			data[1] = (totalPDB3040.doubleValue() / totalPD.doubleValue()) * 100;
			data[2] = (totalPDB4050.doubleValue() / totalPD.doubleValue()) * 100;
			data[3] = (totalPDG50.doubleValue() / totalPD.doubleValue()) * 100;
			
			// Devolvemos los datos
			return data;

		} catch (Exception e) {
			e.printStackTrace();
			return null;
		}
	}


	public double[] getDatosSexo() {
		
		double[] data = new double[2];

		try {
			
			Session sesion = HibernateSessionFactory.getSession();
			// Creamos el sql para recuperar los datos
			Query queryTotales = sesion.createSQLQuery(SQL_TOTAL_PD);
			Query queryHombres = sesion
					.createSQLQuery(SQL_TOTAL_PD_HOMBRES);
			// Recupera los datos de la base de datos
			BigInteger totalPD = (BigInteger) queryTotales.list()
					.get(0);
			BigInteger totalPDHombres = (BigInteger) queryHombres
					.list().get(0);
			// Hacemos el calculo de los datos
			data[0] = (totalPDHombres.doubleValue() / totalPD
					.doubleValue()) * 100;
			data[1] = ((totalPD.doubleValue() - totalPDHombres
					.doubleValue()) / totalPD.doubleValue()) * 100;
			// Devolvemos los datos
			return data;

		} catch (Exception e) {
			e.printStackTrace();
			return null;
		}
	}
}
