package hibernate;

import java.util.List;
import java.util.Set;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.LockMode;
import org.hibernate.Query;
import org.hibernate.criterion.Example;

/**
 * A data access object (DAO) providing persistence and search support for
 * Auxiliar entities. Transaction control of the save(), update() and delete()
 * operations can directly support Spring container-managed transactions or they
 * can be augmented to handle user-managed Spring transactions. Each of these
 * methods provides additional information for how to configure it for the
 * desired type of transaction control.
 * 
 * @see hibernate.Auxiliar
 * @author MyEclipse Persistence Tools
 */

public class AuxiliarDAO extends BaseHibernateDAO {
	private static final Log log = LogFactory.getLog(AuxiliarDAO.class);
	// property constants
	public static final String DISPONIBLE = "disponible";

	public void save(Auxiliar transientInstance) {
		log.debug("saving Auxiliar instance");
		try {
			getSession().save(transientInstance);
			log.debug("save successful");
		} catch (RuntimeException re) {
			log.error("save failed", re);
			throw re;
		}
	}

	public void delete(Auxiliar persistentInstance) {
		log.debug("deleting Auxiliar instance");
		try {
			getSession().delete(persistentInstance);
			log.debug("delete successful");
		} catch (RuntimeException re) {
			log.error("delete failed", re);
			throw re;
		}
	}

	public Auxiliar findById(java.lang.Integer id) {
		log.debug("getting Auxiliar instance with id: " + id);
		try {
			Auxiliar instance = (Auxiliar) getSession().get(
					"hibernate.Auxiliar", id);
			return instance;
		} catch (RuntimeException re) {
			log.error("get failed", re);
			throw re;
		}
	}

	public List findByExample(Auxiliar instance) {
		log.debug("finding Auxiliar instance by example");
		try {
			List results = getSession().createCriteria("hibernate.Auxiliar")
					.add(Example.create(instance)).list();
			log.debug("find by example successful, result size: "
					+ results.size());
			return results;
		} catch (RuntimeException re) {
			log.error("find by example failed", re);
			throw re;
		}
	}

	public List findByProperty(String propertyName, Object value) {
		log.debug("finding Auxiliar instance with property: " + propertyName
				+ ", value: " + value);
		try {
			String queryString = "from Auxiliar as model where model."
					+ propertyName + "= ?";
			Query queryObject = getSession().createQuery(queryString);
			queryObject.setParameter(0, value);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find by property name failed", re);
			throw re;
		}
	}

	public List findByDisponible(Object disponible) {
		return findByProperty(DISPONIBLE, disponible);
	}

	public List findAll() {
		log.debug("finding all Auxiliar instances");
		try {
			String queryString = "from Auxiliar";
			Query queryObject = getSession().createQuery(queryString);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find all failed", re);
			throw re;
		}
	}

	
	public List findAllNoAsignados(Integer id_localidad) {
		log.debug("finding all Auxiliar instances");
		try {
			String queryString = "from Auxiliar where id_asociacion IS NULL and usuario.persona.localidad.id = " + id_localidad.toString();
			Query queryObject = getSession().createQuery(queryString);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find all failed", re);
			throw re;
		}
	}
	
	public List findAllAsociacion(String id_asociacion) {
		log.debug("finding all Auxiliar instances");
		try {
			String queryString = "from Auxiliar where id_asociacion = " + id_asociacion;
			Query queryObject = getSession().createQuery(queryString);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find all failed", re);
			throw re;
		}
	}
	
	
	
	public Auxiliar merge(Auxiliar detachedInstance) {
		log.debug("merging Auxiliar instance");
		try {
			Auxiliar result = (Auxiliar) getSession().merge(detachedInstance);
			log.debug("merge successful");
			return result;
		} catch (RuntimeException re) {
			log.error("merge failed", re);
			throw re;
		}
	}

	public void attachDirty(Auxiliar instance) {
		log.debug("attaching dirty Auxiliar instance");
		try {
			getSession().saveOrUpdate(instance);
			log.debug("attach successful");
		} catch (RuntimeException re) {
			log.error("attach failed", re);
			throw re;
		}
	}

	public void attachClean(Auxiliar instance) {
		log.debug("attaching clean Auxiliar instance");
		try {
			getSession().lock(instance, LockMode.NONE);
			log.debug("attach successful");
		} catch (RuntimeException re) {
			log.error("attach failed", re);
			throw re;
		}
	}
}