package hibernate;

import java.util.Date;
import java.util.List;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.LockMode;
import org.hibernate.Query;
import org.hibernate.criterion.Example;

/**
 * A data access object (DAO) providing persistence and search support for
 * Consulta entities. Transaction control of the save(), update() and delete()
 * operations can directly support Spring container-managed transactions or they
 * can be augmented to handle user-managed Spring transactions. Each of these
 * methods provides additional information for how to configure it for the
 * desired type of transaction control.
 * 
 * @see hibernate.Consulta
 * @author MyEclipse Persistence Tools
 */

public class ConsultaDAO extends BaseHibernateDAO {
	private static final Log log = LogFactory.getLog(ConsultaDAO.class);
	// property constants
	public static final String PREGUNTA = "pregunta";
	public static final String RESPUESTA = "respuesta";

	public void save(Consulta transientInstance) {
		log.debug("saving Consulta instance");
		try {
			getSession().save(transientInstance);
			log.debug("save successful");
		} catch (RuntimeException re) {
			log.error("save failed", re);
			throw re;
		}
	}

	public void delete(Consulta persistentInstance) {
		log.debug("deleting Consulta instance");
		try {
			getSession().delete(persistentInstance);
			log.debug("delete successful");
		} catch (RuntimeException re) {
			log.error("delete failed", re);
			throw re;
		}
	}

	public Consulta findById(java.lang.Integer id) {
		log.debug("getting Consulta instance with id: " + id);
		try {
			Consulta instance = (Consulta) getSession().get(
					"hibernate.Consulta", id);
			return instance;
		} catch (RuntimeException re) {
			log.error("get failed", re);
			throw re;
		}
	}

	public List findByExample(Consulta instance) {
		log.debug("finding Consulta instance by example");
		try {
			List results = getSession().createCriteria("hibernate.Consulta")
					.add(Example.create(instance)).list();
			log.debug("find by example successful, result size: "
					+ results.size());
			return results;
		} catch (RuntimeException re) {
			log.error("find by example failed", re);
			throw re;
		}
	}

	public List findByProperty(String propertyName, Object value) {
		log.debug("finding Consulta instance with property: " + propertyName
				+ ", value: " + value);
		try {
			String queryString = "from Consulta as model where model."
					+ propertyName + "= ?";
			Query queryObject = getSession().createQuery(queryString);
			queryObject.setParameter(0, value);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find by property name failed", re);
			throw re;
		}
	}

	public List findByPregunta(Object pregunta) {
		return findByProperty(PREGUNTA, pregunta);
	}

	public List findByRespuesta(Object respuesta) {
		return findByProperty(RESPUESTA, respuesta);
	}

	public List findAll() {
		log.debug("finding all Consulta instances");
		try {
			String queryString = "from Consulta WHERE fec_respuesta IS NULL";
			Query queryObject = getSession().createQuery(queryString);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find all failed", re);
			throw re;
		}
	}
	
	public List findAllVol(String id) {
		log.debug("finding all Consulta instances");
		try {
			String queryString = "from Consulta where id_voluntario = " + id + "AND fec_respuesta IS NULL";
			Query queryObject = getSession().createQuery(queryString);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find all failed", re);
			throw re;
		}
	}
	
	public List findAllAso(String id) {
		log.debug("finding all Consulta instances");
		try {
			String queryString = "from Consulta where id_pd = " + id + "AND fec_respuesta IS NULL";
			Query queryObject = getSession().createQuery(queryString);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find all failed", re);
			throw re;
		}
	}
	
	public List findAllAsoRes(String id) {
		log.debug("finding all Consulta instances");
		try {
			String queryString = "from Consulta where id_pd = " + id + "AND fec_respuesta IS NOT NULL";
			Query queryObject = getSession().createQuery(queryString);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find all failed", re);
			throw re;
		}
	}

	public Consulta merge(Consulta detachedInstance) {
		log.debug("merging Consulta instance");
		try {
			Consulta result = (Consulta) getSession().merge(detachedInstance);
			log.debug("merge successful");
			return result;
		} catch (RuntimeException re) {
			log.error("merge failed", re);
			throw re;
		}
	}

	public void attachDirty(Consulta instance) {
		log.debug("attaching dirty Consulta instance");
		try {
			getSession().saveOrUpdate(instance);
			log.debug("attach successful");
		} catch (RuntimeException re) {
			log.error("attach failed", re);
			throw re;
		}
	}

	public void attachClean(Consulta instance) {
		log.debug("attaching clean Consulta instance");
		try {
			getSession().lock(instance, LockMode.NONE);
			log.debug("attach successful");
		} catch (RuntimeException re) {
			log.error("attach failed", re);
			throw re;
		}
	}
}