package hibernate;

import java.util.Date;
import java.util.List;
import java.util.Set;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.LockMode;
import org.hibernate.Query;
import org.hibernate.criterion.Example;

/**
 * A data access object (DAO) providing persistence and search support for
 * Evento entities. Transaction control of the save(), update() and delete()
 * operations can directly support Spring container-managed transactions or they
 * can be augmented to handle user-managed Spring transactions. Each of these
 * methods provides additional information for how to configure it for the
 * desired type of transaction control.
 * 
 * @see hibernate.Evento
 * @author MyEclipse Persistence Tools
 */

public class EventoDAO extends BaseHibernateDAO {
	private static final Log log = LogFactory.getLog(EventoDAO.class);
	// property constants
	public static final String NUM_DIAS_SEMANALES = "numDiasSemanales";
	public static final String NUM_HORAS_SEMANALES = "numHorasSemanales";

	public void save(Evento transientInstance) {
		log.debug("saving Evento instance");
		try {
			getSession().save(transientInstance);
			log.debug("save successful");
		} catch (RuntimeException re) {
			log.error("save failed", re);
			throw re;
		}
	}

	public void delete(Evento persistentInstance) {
		log.debug("deleting Evento instance");
		try {
			getSession().delete(persistentInstance);
			log.debug("delete successful");
		} catch (RuntimeException re) {
			log.error("delete failed", re);
			throw re;
		}
	}

	public Evento findById(java.lang.Integer id) {
		log.debug("getting Evento instance with id: " + id);
		try {
			Evento instance = (Evento) getSession().get("hibernate.Evento", id);
			return instance;
		} catch (RuntimeException re) {
			log.error("get failed", re);
			throw re;
		}
	}

	public List findByExample(Evento instance) {
		log.debug("finding Evento instance by example");
		try {
			List results = getSession().createCriteria("hibernate.Evento").add(
					Example.create(instance)).list();
			log.debug("find by example successful, result size: "
					+ results.size());
			return results;
		} catch (RuntimeException re) {
			log.error("find by example failed", re);
			throw re;
		}
	}

	public List findByProperty(String propertyName, Object value) {
		log.debug("finding Evento instance with property: " + propertyName
				+ ", value: " + value);
		try {
			String queryString = "from Evento as model where model."
					+ propertyName + "= ?";
			Query queryObject = getSession().createQuery(queryString);
			queryObject.setParameter(0, value);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find by property name failed", re);
			throw re;
		}
	}

	public List findByNumDiasSemanales(Object numDiasSemanales) {
		return findByProperty(NUM_DIAS_SEMANALES, numDiasSemanales);
	}

	public List findByNumHorasSemanales(Object numHorasSemanales) {
		return findByProperty(NUM_HORAS_SEMANALES, numHorasSemanales);
	}

	public List findAll() {
		log.debug("finding all Evento instances");
		try {
			String queryString = "from Evento";
			Query queryObject = getSession().createQuery(queryString);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find all failed", re);
			throw re;
		}
	}

	public Evento merge(Evento detachedInstance) {
		log.debug("merging Evento instance");
		try {
			Evento result = (Evento) getSession().merge(detachedInstance);
			log.debug("merge successful");
			return result;
		} catch (RuntimeException re) {
			log.error("merge failed", re);
			throw re;
		}
	}

	public void attachDirty(Evento instance) {
		log.debug("attaching dirty Evento instance");
		try {
			getSession().saveOrUpdate(instance);
			log.debug("attach successful");
		} catch (RuntimeException re) {
			log.error("attach failed", re);
			throw re;
		}
	}

	public void attachClean(Evento instance) {
		log.debug("attaching clean Evento instance");
		try {
			getSession().lock(instance, LockMode.NONE);
			log.debug("attach successful");
		} catch (RuntimeException re) {
			log.error("attach failed", re);
			throw re;
		}
	}
}