package hibernate;

import java.util.Date;
import java.util.List;
import java.util.Set;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.LockMode;
import org.hibernate.Query;
import org.hibernate.criterion.Example;

/**
 * A data access object (DAO) providing persistence and search support for
 * Expediente entities. Transaction control of the save(), update() and delete()
 * operations can directly support Spring container-managed transactions or they
 * can be augmented to handle user-managed Spring transactions. Each of these
 * methods provides additional information for how to configure it for the
 * desired type of transaction control.
 * 
 * @see hibernate.Expediente
 * @author MyEclipse Persistence Tools
 */

public class ExpedienteDAO extends BaseHibernateDAO {
	private static final Log log = LogFactory.getLog(ExpedienteDAO.class);
	// property constants
	public static final String LISTA_ESPERA = "listaEspera";
	public static final String CONCEDIDO = "concedido";
	public static final String MOTIVO_DENEGACION = "motivoDenegacion";
	public static final String TOTAL_PUNTUACION = "totalPuntuacion";

	public void save(Expediente transientInstance) {
		log.debug("saving Expediente instance");
		try {
			getSession().save(transientInstance);
			log.debug("save successful");
		} catch (RuntimeException re) {
			log.error("save failed", re);
			throw re;
		}
	}

	public void delete(Expediente persistentInstance) {
		log.debug("deleting Expediente instance");
		try {
			getSession().delete(persistentInstance);
			log.debug("delete successful");
		} catch (RuntimeException re) {
			log.error("delete failed", re);
			throw re;
		}
	}

	public Expediente findById(java.lang.Integer id) {
		log.debug("getting Expediente instance with id: " + id);
		try {
			Expediente instance = (Expediente) getSession().get(
					"hibernate.Expediente", id);
			return instance;
		} catch (RuntimeException re) {
			log.error("get failed", re);
			throw re;
		}
	}

	public List findByExample(Expediente instance) {
		log.debug("finding Expediente instance by example");
		try {
			List results = getSession().createCriteria("hibernate.Expediente")
					.add(Example.create(instance)).list();
			log.debug("find by example successful, result size: "
					+ results.size());
			return results;
		} catch (RuntimeException re) {
			log.error("find by example failed", re);
			throw re;
		}
	}

	public List findByProperty(String propertyName, Object value) {
		log.debug("finding Expediente instance with property: " + propertyName
				+ ", value: " + value);
		try {
			String queryString = "from Expediente as model where model."
					+ propertyName + "= ?";
			Query queryObject = getSession().createQuery(queryString);
			queryObject.setParameter(0, value);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find by property name failed", re);
			throw re;
		}
	}

	public List findByListaEspera(Object listaEspera) {
		return findByProperty(LISTA_ESPERA, listaEspera);
	}

	public List findByConcedido(Object concedido) {
		return findByProperty(CONCEDIDO, concedido);
	}

	public List findByMotivoDenegacion(Object motivoDenegacion) {
		return findByProperty(MOTIVO_DENEGACION, motivoDenegacion);
	}

	public List findByTotalPuntuacion(Object totalPuntuacion) {
		return findByProperty(TOTAL_PUNTUACION, totalPuntuacion);
	}

	public List findAll() {
		log.debug("finding all Expediente instances");
		try {
			String queryString = "from Expediente";
			Query queryObject = getSession().createQuery(queryString);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find all failed", re);
			throw re;
		}
	}

	public Expediente merge(Expediente detachedInstance) {
		log.debug("merging Expediente instance");
		try {
			Expediente result = (Expediente) getSession().merge(
					detachedInstance);
			log.debug("merge successful");
			return result;
		} catch (RuntimeException re) {
			log.error("merge failed", re);
			throw re;
		}
	}

	public void attachDirty(Expediente instance) {
		log.debug("attaching dirty Expediente instance");
		try {
			getSession().saveOrUpdate(instance);
			log.debug("attach successful");
		} catch (RuntimeException re) {
			log.error("attach failed", re);
			throw re;
		}
	}

	public void attachClean(Expediente instance) {
		log.debug("attaching clean Expediente instance");
		try {
			getSession().lock(instance, LockMode.NONE);
			log.debug("attach successful");
		} catch (RuntimeException re) {
			log.error("attach failed", re);
			throw re;
		}
	}
}