package hibernate;

import java.util.List;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.LockMode;
import org.hibernate.Query;
import org.hibernate.criterion.Example;

/**
 * A data access object (DAO) providing persistence and search support for Hora
 * entities. Transaction control of the save(), update() and delete() operations
 * can directly support Spring container-managed transactions or they can be
 * augmented to handle user-managed Spring transactions. Each of these methods
 * provides additional information for how to configure it for the desired type
 * of transaction control.
 * 
 * @see hibernate.Hora
 * @author MyEclipse Persistence Tools
 */

public class HoraDAO extends BaseHibernateDAO {
	private static final Log log = LogFactory.getLog(HoraDAO.class);
	// property constants
	public static final String INTERVALO = "intervalo";

	public void save(Hora transientInstance) {
		log.debug("saving Hora instance");
		try {
			getSession().save(transientInstance);
			log.debug("save successful");
		} catch (RuntimeException re) {
			log.error("save failed", re);
			throw re;
		}
	}

	public void delete(Hora persistentInstance) {
		log.debug("deleting Hora instance");
		try {
			getSession().delete(persistentInstance);
			log.debug("delete successful");
		} catch (RuntimeException re) {
			log.error("delete failed", re);
			throw re;
		}
	}

	public Hora findById(java.lang.Integer id) {
		log.debug("getting Hora instance with id: " + id);
		try {
			Hora instance = (Hora) getSession().get("hibernate.Hora", id);
			return instance;
		} catch (RuntimeException re) {
			log.error("get failed", re);
			throw re;
		}
	}

	public List findByExample(Hora instance) {
		log.debug("finding Hora instance by example");
		try {
			List results = getSession().createCriteria("hibernate.Hora").add(
					Example.create(instance)).list();
			log.debug("find by example successful, result size: "
					+ results.size());
			return results;
		} catch (RuntimeException re) {
			log.error("find by example failed", re);
			throw re;
		}
	}

	public List findByProperty(String propertyName, Object value) {
		log.debug("finding Hora instance with property: " + propertyName
				+ ", value: " + value);
		try {
			String queryString = "from Hora as model where model."
					+ propertyName + "= ?";
			Query queryObject = getSession().createQuery(queryString);
			queryObject.setParameter(0, value);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find by property name failed", re);
			throw re;
		}
	}

	public List findByIntervalo(Object intervalo) {
		return findByProperty(INTERVALO, intervalo);
	}

	public List findAll() {
		log.debug("finding all Hora instances");
		try {
			String queryString = "from Hora ORDER BY id ASC";
			Query queryObject = getSession().createQuery(queryString);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find all failed", re);
			throw re;
		}
	}

	public Hora merge(Hora detachedInstance) {
		log.debug("merging Hora instance");
		try {
			Hora result = (Hora) getSession().merge(detachedInstance);
			log.debug("merge successful");
			return result;
		} catch (RuntimeException re) {
			log.error("merge failed", re);
			throw re;
		}
	}

	public void attachDirty(Hora instance) {
		log.debug("attaching dirty Hora instance");
		try {
			getSession().saveOrUpdate(instance);
			log.debug("attach successful");
		} catch (RuntimeException re) {
			log.error("attach failed", re);
			throw re;
		}
	}

	public void attachClean(Hora instance) {
		log.debug("attaching clean Hora instance");
		try {
			getSession().lock(instance, LockMode.NONE);
			log.debug("attach successful");
		} catch (RuntimeException re) {
			log.error("attach failed", re);
			throw re;
		}
	}
}