package hibernate;

import java.util.Date;
import java.util.List;
import java.util.Set;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.LockMode;
import org.hibernate.Query;
import org.hibernate.criterion.Example;

/**
 * A data access object (DAO) providing persistence and search support for
 * Persona entities. Transaction control of the save(), update() and delete()
 * operations can directly support Spring container-managed transactions or they
 * can be augmented to handle user-managed Spring transactions. Each of these
 * methods provides additional information for how to configure it for the
 * desired type of transaction control.
 * 
 * @see hibernate.Persona
 * @author MyEclipse Persistence Tools
 */

public class PersonaDAO extends BaseHibernateDAO {
	private static final Log log = LogFactory.getLog(PersonaDAO.class);
	// property constants
	public static final String NOMBRE = "nombre";
	public static final String APELLIDO1 = "apellido1";
	public static final String APELLIDO2 = "apellido2";
	public static final String DIRECCION = "direccion";
	public static final String TELEFONO = "telefono";
	public static final String MOVIL = "movil";
	public static final String CODIGO_POSTAL = "codigoPostal";
	public static final String EMAIL = "email";
	public static final String DNI = "dni";

	public void save(Persona transientInstance) {
		log.debug("saving Persona instance");
		try {
			getSession().save(transientInstance);
			log.debug("save successful");
		} catch (RuntimeException re) {
			log.error("save failed", re);
			throw re;
		}
	}

	public void delete(Persona persistentInstance) {
		log.debug("deleting Persona instance");
		try {
			getSession().delete(persistentInstance);
			log.debug("delete successful");
		} catch (RuntimeException re) {
			log.error("delete failed", re);
			throw re;
		}
	}

	public Persona findById(java.lang.Integer id) {
		log.debug("getting Persona instance with id: " + id);
		try {
			Persona instance = (Persona) getSession().get("hibernate.Persona",
					id);
			return instance;
		} catch (RuntimeException re) {
			log.error("get failed", re);
			throw re;
		}
	}

	public List findByExample(Persona instance) {
		log.debug("finding Persona instance by example");
		try {
			List results = getSession().createCriteria("hibernate.Persona")
					.add(Example.create(instance)).list();
			log.debug("find by example successful, result size: "
					+ results.size());
			return results;
		} catch (RuntimeException re) {
			log.error("find by example failed", re);
			throw re;
		}
	}

	public List findByProperty(String propertyName, Object value) {
		log.debug("finding Persona instance with property: " + propertyName
				+ ", value: " + value);
		try {
			String queryString = "from Persona as model where model."
					+ propertyName + "= ?";
			Query queryObject = getSession().createQuery(queryString);
			queryObject.setParameter(0, value);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find by property name failed", re);
			throw re;
		}
	}

	public List findByNombre(Object nombre) {
		return findByProperty(NOMBRE, nombre);
	}

	public List findByApellido1(Object apellido1) {
		return findByProperty(APELLIDO1, apellido1);
	}

	public List findByApellido2(Object apellido2) {
		return findByProperty(APELLIDO2, apellido2);
	}

	public List findByDireccion(Object direccion) {
		return findByProperty(DIRECCION, direccion);
	}

	public List findByTelefono(Object telefono) {
		return findByProperty(TELEFONO, telefono);
	}

	public List findByMovil(Object movil) {
		return findByProperty(MOVIL, movil);
	}

	public List findByCodigoPostal(Object codigoPostal) {
		return findByProperty(CODIGO_POSTAL, codigoPostal);
	}

	public List findByEmail(Object email) {
		return findByProperty(EMAIL, email);
	}

	public List findByDni(Object dni) {
		return findByProperty(DNI, dni);
	}

	public List findAll() {
		log.debug("finding all Persona instances");
		try {
			String queryString = "from Persona";
			Query queryObject = getSession().createQuery(queryString);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find all failed", re);
			throw re;
		}
	}

	public Persona merge(Persona detachedInstance) {
		log.debug("merging Persona instance");
		try {
			Persona result = (Persona) getSession().merge(detachedInstance);
			log.debug("merge successful");
			return result;
		} catch (RuntimeException re) {
			log.error("merge failed", re);
			throw re;
		}
	}

	public void attachDirty(Persona instance) {
		log.debug("attaching dirty Persona instance");
		try {
			getSession().saveOrUpdate(instance);
			log.debug("attach successful");
		} catch (RuntimeException re) {
			log.error("attach failed", re);
			throw re;
		}
	}

	public void attachClean(Persona instance) {
		log.debug("attaching clean Persona instance");
		try {
			getSession().lock(instance, LockMode.NONE);
			log.debug("attach successful");
		} catch (RuntimeException re) {
			log.error("attach failed", re);
			throw re;
		}
	}
}