package hibernate;

import java.util.Date;
import java.util.List;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.LockMode;
import org.hibernate.Query;
import org.hibernate.criterion.Example;

/**
 * A data access object (DAO) providing persistence and search support for
 * PersonaDependiente entities. Transaction control of the save(), update() and
 * delete() operations can directly support Spring container-managed
 * transactions or they can be augmented to handle user-managed Spring
 * transactions. Each of these methods provides additional information for how
 * to configure it for the desired type of transaction control.
 * 
 * @see hibernate.PersonaDependiente
 * @author MyEclipse Persistence Tools
 */

public class PersonaDependienteDAO extends BaseHibernateDAO {
	private static final Log log = LogFactory
			.getLog(PersonaDependienteDAO.class);
	// property constants
	public static final String MEDICO_CABECERA = "medicoCabecera";
	public static final String CENTRO_SALUD = "centroSalud";
	public static final String DISCAPACIDAD = "discapacidad";
	public static final String CAUSA_BAJA = "causaBaja";
	public static final String SEXO = "sexo";
	public static final String ESTADO_CIVIL = "estadoCivil";
	public static final String PUEDE_FIRMAR = "puedeFirmar";

	public void save(PersonaDependiente transientInstance) {
		log.debug("saving PersonaDependiente instance");
		try {
			getSession().save(transientInstance);
			log.debug("save successful");
		} catch (RuntimeException re) {
			log.error("save failed", re);
			throw re;
		}
	}

	public void delete(PersonaDependiente persistentInstance) {
		log.debug("deleting PersonaDependiente instance");
		try {
			getSession().delete(persistentInstance);
			log.debug("delete successful");
		} catch (RuntimeException re) {
			log.error("delete failed", re);
			throw re;
		}
	}

	public PersonaDependiente findById(java.lang.Integer id) {
		log.debug("getting PersonaDependiente instance with id: " + id);
		try {
			PersonaDependiente instance = (PersonaDependiente) getSession()
					.get("hibernate.PersonaDependiente", id);
			return instance;
		} catch (RuntimeException re) {
			log.error("get failed", re);
			throw re;
		}
	}

	public List findByExample(PersonaDependiente instance) {
		log.debug("finding PersonaDependiente instance by example");
		try {
			List results = getSession().createCriteria(
					"hibernate.PersonaDependiente").add(
					Example.create(instance)).list();
			log.debug("find by example successful, result size: "
					+ results.size());
			return results;
		} catch (RuntimeException re) {
			log.error("find by example failed", re);
			throw re;
		}
	}

	public List findByProperty(String propertyName, Object value) {
		log.debug("finding PersonaDependiente instance with property: "
				+ propertyName + ", value: " + value);
		try {
			String queryString = "from PersonaDependiente as model where model."
					+ propertyName + "= ?";
			Query queryObject = getSession().createQuery(queryString);
			queryObject.setParameter(0, value);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find by property name failed", re);
			throw re;
		}
	}


	public List findByMedicoCabecera(Object medicoCabecera) {
		return findByProperty(MEDICO_CABECERA, medicoCabecera);
	}

	public List findByCentroSalud(Object centroSalud) {
		return findByProperty(CENTRO_SALUD, centroSalud);
	}

	public List findByDiscapacidad(Object discapacidad) {
		return findByProperty(DISCAPACIDAD, discapacidad);
	}

	public List findByCausaBaja(Object causaBaja) {
		return findByProperty(CAUSA_BAJA, causaBaja);
	}

	public List findBySexo(Object sexo) {
		return findByProperty(SEXO, sexo);
	}

	public List findByEstadoCivil(Object estadoCivil) {
		return findByProperty(ESTADO_CIVIL, estadoCivil);
	}

	public List findByPuedeFirmar(Object puedeFirmar) {
		return findByProperty(PUEDE_FIRMAR, puedeFirmar);
	}

	public List findAll() {
		log.debug("finding all PersonaDependiente instances");
		try {
			String queryString = "from PersonaDependiente";
			Query queryObject = getSession().createQuery(queryString);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find all failed", re);
			throw re;
		}
	}
	
	
	public List findAllAsociacion(Integer id_asociacion) {
		log.debug("finding all PersonaDependiente instances");
		try {
			String queryString = "from PersonaDependiente where id_asociacion = " + id_asociacion.toString();
			Query queryObject = getSession().createQuery(queryString);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find all failed", re);
			throw re;
		}
	}
	
	
	public List findAllDesasignados(String id_asociacion) {
		log.debug("finding all PersonaDependiente instances");
		try {
			String queryString = "from PersonaDependiente where id_auxiliar IS NULL and id_asociacion = " + id_asociacion;
			Query queryObject = getSession().createQuery(queryString);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find all failed", re);
			throw re;
		}
	}
	
	
	public List findAllAsignados(String id) {
		log.debug("finding all PersonaDependiente instances");
		try {
			String queryString = "from PersonaDependiente where id_auxiliar = " + id;
			Query queryObject = getSession().createQuery(queryString);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find all failed", re);
			throw re;
		}
	}
	
	
	public PersonaDependiente merge(PersonaDependiente detachedInstance) {
		log.debug("merging PersonaDependiente instance");
		try {
			PersonaDependiente result = (PersonaDependiente) getSession()
					.merge(detachedInstance);
			log.debug("merge successful");
			return result;
		} catch (RuntimeException re) {
			log.error("merge failed", re);
			throw re;
		}
	}

	public void attachDirty(PersonaDependiente instance) {
		log.debug("attaching dirty PersonaDependiente instance");
		try {
			getSession().saveOrUpdate(instance);
			log.debug("attach successful");
		} catch (RuntimeException re) {
			log.error("attach failed", re);
			throw re;
		}
	}

	public void attachClean(PersonaDependiente instance) {
		log.debug("attaching clean PersonaDependiente instance");
		try {
			getSession().lock(instance, LockMode.NONE);
			log.debug("attach successful");
		} catch (RuntimeException re) {
			log.error("attach failed", re);
			throw re;
		}
	}
}