package hibernate;

import java.util.List;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.LockMode;
import org.hibernate.Query;
import org.hibernate.criterion.Example;

/**
 * A data access object (DAO) providing persistence and search support for
 * RespuestaEstadoFisico entities. Transaction control of the save(), update()
 * and delete() operations can directly support Spring container-managed
 * transactions or they can be augmented to handle user-managed Spring
 * transactions. Each of these methods provides additional information for how
 * to configure it for the desired type of transaction control.
 * 
 * @see hibernate.RespuestaEstadoFisico
 * @author MyEclipse Persistence Tools
 */

public class RespuestaEstadoFisicoDAO extends BaseHibernateDAO {
	private static final Log log = LogFactory
			.getLog(RespuestaEstadoFisicoDAO.class);
	// property constants
	public static final String PUNTUACION = "puntuacion";

	public void save(RespuestaEstadoFisico transientInstance) {
		log.debug("saving RespuestaEstadoFisico instance");
		try {
			getSession().save(transientInstance);
			log.debug("save successful");
		} catch (RuntimeException re) {
			log.error("save failed", re);
			throw re;
		}
	}

	public void delete(RespuestaEstadoFisico persistentInstance) {
		log.debug("deleting RespuestaEstadoFisico instance");
		try {
			getSession().delete(persistentInstance);
			log.debug("delete successful");
		} catch (RuntimeException re) {
			log.error("delete failed", re);
			throw re;
		}
	}

	public RespuestaEstadoFisico findById(java.lang.Integer id) {
		log.debug("getting RespuestaEstadoFisico instance with id: " + id);
		try {
			RespuestaEstadoFisico instance = (RespuestaEstadoFisico) getSession()
					.get("hibernate.RespuestaEstadoFisico", id);
			return instance;
		} catch (RuntimeException re) {
			log.error("get failed", re);
			throw re;
		}
	}

	public List findByExample(RespuestaEstadoFisico instance) {
		log.debug("finding RespuestaEstadoFisico instance by example");
		try {
			List results = getSession().createCriteria(
					"hibernate.RespuestaEstadoFisico").add(
					Example.create(instance)).list();
			log.debug("find by example successful, result size: "
					+ results.size());
			return results;
		} catch (RuntimeException re) {
			log.error("find by example failed", re);
			throw re;
		}
	}

	public List findByProperty(String propertyName, Object value) {
		log.debug("finding RespuestaEstadoFisico instance with property: "
				+ propertyName + ", value: " + value);
		try {
			String queryString = "from RespuestaEstadoFisico as model where model."
					+ propertyName + "= ?";
			Query queryObject = getSession().createQuery(queryString);
			queryObject.setParameter(0, value);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find by property name failed", re);
			throw re;
		}
	}

	public List findByPuntuacion(Object puntuacion) {
		return findByProperty(PUNTUACION, puntuacion);
	}

	public List findAll() {
		log.debug("finding all RespuestaEstadoFisico instances");
		try {
			String queryString = "from RespuestaEstadoFisico";
			Query queryObject = getSession().createQuery(queryString);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find all failed", re);
			throw re;
		}
	}

	public RespuestaEstadoFisico merge(RespuestaEstadoFisico detachedInstance) {
		log.debug("merging RespuestaEstadoFisico instance");
		try {
			RespuestaEstadoFisico result = (RespuestaEstadoFisico) getSession()
					.merge(detachedInstance);
			log.debug("merge successful");
			return result;
		} catch (RuntimeException re) {
			log.error("merge failed", re);
			throw re;
		}
	}

	public void attachDirty(RespuestaEstadoFisico instance) {
		log.debug("attaching dirty RespuestaEstadoFisico instance");
		try {
			getSession().saveOrUpdate(instance);
			log.debug("attach successful");
		} catch (RuntimeException re) {
			log.error("attach failed", re);
			throw re;
		}
	}

	public void attachClean(RespuestaEstadoFisico instance) {
		log.debug("attaching clean RespuestaEstadoFisico instance");
		try {
			getSession().lock(instance, LockMode.NONE);
			log.debug("attach successful");
		} catch (RuntimeException re) {
			log.error("attach failed", re);
			throw re;
		}
	}
}