package hibernate;

import java.util.List;
import java.util.Set;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.LockMode;
import org.hibernate.Query;
import org.hibernate.criterion.Example;

/**
 * A data access object (DAO) providing persistence and search support for
 * Servicio entities. Transaction control of the save(), update() and delete()
 * operations can directly support Spring container-managed transactions or they
 * can be augmented to handle user-managed Spring transactions. Each of these
 * methods provides additional information for how to configure it for the
 * desired type of transaction control.
 * 
 * @see hibernate.Servicio
 * @author MyEclipse Persistence Tools
 */

public class ServicioDAO extends BaseHibernateDAO {
	private static final Log log = LogFactory.getLog(ServicioDAO.class);
	// property constants
	public static final String NOTAS = "notas";

	public void save(Servicio transientInstance) {
		log.debug("saving Servicio instance");
		try {
			getSession().save(transientInstance);
			log.debug("save successful");
		} catch (RuntimeException re) {
			log.error("save failed", re);
			throw re;
		}
	}

	public void delete(Servicio persistentInstance) {
		log.debug("deleting Servicio instance");
		try {
			getSession().delete(persistentInstance);
			log.debug("delete successful");
		} catch (RuntimeException re) {
			log.error("delete failed", re);
			throw re;
		}
	}

	public Servicio findById(java.lang.Integer id) {
		log.debug("getting Servicio instance with id: " + id);
		try {
			Servicio instance = (Servicio) getSession().get(
					"hibernate.Servicio", id);
			return instance;
		} catch (RuntimeException re) {
			log.error("get failed", re);
			throw re;
		}
	}

	public List findByExample(Servicio instance) {
		log.debug("finding Servicio instance by example");
		try {
			List results = getSession().createCriteria("hibernate.Servicio")
					.add(Example.create(instance)).list();
			log.debug("find by example successful, result size: "
					+ results.size());
			return results;
		} catch (RuntimeException re) {
			log.error("find by example failed", re);
			throw re;
		}
	}

	public List findByProperty(String propertyName, Object value) {
		log.debug("finding Servicio instance with property: " + propertyName
				+ ", value: " + value);
		try {
			String queryString = "from Servicio as model where model."
					+ propertyName + "= ?";
			Query queryObject = getSession().createQuery(queryString);
			queryObject.setParameter(0, value);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find by property name failed", re);
			throw re;
		}
	}

	public List findByNotas(Object notas) {
		return findByProperty(NOTAS, notas);
	}

	public List findAll() {
		log.debug("finding all Servicio instances");
		try {
			String queryString = "from Servicio";
			Query queryObject = getSession().createQuery(queryString);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find all failed", re);
			throw re;
		}
	}
	
	public List findAllDia(String dia, String id_vol) {
		log.debug("finding all Servicio instances con id_voluntario y dia");
		try {
			String queryString = "from Servicio where dia = " + dia + " AND id_voluntario = " + id_vol + " ORDER BY hora_inicio ASC";
			Query queryObject = getSession().createQuery(queryString);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find all failed", re);
			throw re;
		}
	}

	public Servicio merge(Servicio detachedInstance) {
		log.debug("merging Servicio instance");
		try {
			Servicio result = (Servicio) getSession().merge(detachedInstance);
			log.debug("merge successful");
			return result;
		} catch (RuntimeException re) {
			log.error("merge failed", re);
			throw re;
		}
	}

	public void attachDirty(Servicio instance) {
		log.debug("attaching dirty Servicio instance");
		try {
			getSession().saveOrUpdate(instance);
			log.debug("attach successful");
		} catch (RuntimeException re) {
			log.error("attach failed", re);
			throw re;
		}
	}

	public void attachClean(Servicio instance) {
		log.debug("attaching clean Servicio instance");
		try {
			getSession().lock(instance, LockMode.NONE);
			log.debug("attach successful");
		} catch (RuntimeException re) {
			log.error("attach failed", re);
			throw re;
		}
	}
}