package hibernate;

import java.util.List;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.LockMode;
import org.hibernate.Query;
import org.hibernate.criterion.Example;

/**
 * A data access object (DAO) providing persistence and search support for
 * VistaPd entities. Transaction control of the save(), update() and delete()
 * operations can directly support Spring container-managed transactions or they
 * can be augmented to handle user-managed Spring transactions. Each of these
 * methods provides additional information for how to configure it for the
 * desired type of transaction control.
 * 
 * @see hibernate.VistaPd
 * @author MyEclipse Persistence Tools
 */

public class VistaPdDAO extends BaseHibernateDAO {
	private static final Log log = LogFactory.getLog(VistaPdDAO.class);

	// property constants

	public void save(VistaPd transientInstance) {
		log.debug("saving VistaPd instance");
		try {
			getSession().save(transientInstance);
			log.debug("save successful");
		} catch (RuntimeException re) {
			log.error("save failed", re);
			throw re;
		}
	}

	public void delete(VistaPd persistentInstance) {
		log.debug("deleting VistaPd instance");
		try {
			getSession().delete(persistentInstance);
			log.debug("delete successful");
		} catch (RuntimeException re) {
			log.error("delete failed", re);
			throw re;
		}
	}

	public VistaPd findById(hibernate.VistaPdId id) {
		log.debug("getting VistaPd instance with id: " + id);
		try {
			VistaPd instance = (VistaPd) getSession().get("hibernate.VistaPd",
					id);
			return instance;
		} catch (RuntimeException re) {
			log.error("get failed", re);
			throw re;
		}
	}

	public List findByExample(VistaPd instance) {
		log.debug("finding VistaPd instance by example");
		try {
			List results = getSession().createCriteria("hibernate.VistaPd")
					.add(Example.create(instance)).list();
			log.debug("find by example successful, result size: "
					+ results.size());
			return results;
		} catch (RuntimeException re) {
			log.error("find by example failed", re);
			throw re;
		}
	}

	public List findByProperty(String propertyName, Object value) {
		log.debug("finding VistaPd instance with property: " + propertyName
				+ ", value: " + value);
		try {
			String queryString = "from VistaPd as model where model."
					+ propertyName + "= ?";
			Query queryObject = getSession().createQuery(queryString);
			queryObject.setParameter(0, value);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find by property name failed", re);
			throw re;
		}
	}

	public List findAll() {
		log.debug("finding all VistaPd instances");
		try {
			String queryString = "from VistaPd";
			Query queryObject = getSession().createQuery(queryString);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find all failed", re);
			throw re;
		}
	}

	
	public List findAllAsociacion(String id_asociacion) {
		log.debug("finding all VistaPd instances");
		try {
			String queryString = "from VistaPd where id_asociacion is not null and id_asociacion = " + id_asociacion;
			Query queryObject = getSession().createQuery(queryString);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find all failed", re);
			throw re;
		}
	}
	
	
	public List findAllAsociacionVoluntario(String id_asociacion, String id_vol) {
		log.debug("finding all VistaPd instances");
		try {
			String queryString = "from VistaPd where id_asociacion = " + id_asociacion + " AND id_auxiliar = " + id_vol;
			Query queryObject = getSession().createQuery(queryString);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find all failed", re);
			throw re;
		}
	}
	
	public List findAllVoluntario(String id_vol) {
		log.debug("finding all VistaPd instances");
		try {
			String queryString = "from VistaPd where id_auxiliar = " + id_vol;
			Query queryObject = getSession().createQuery(queryString);
			return queryObject.list();
		} catch (RuntimeException re) {
			log.error("find all failed", re);
			throw re;
		}
	}
	
	
	public VistaPd merge(VistaPd detachedInstance) {
		log.debug("merging VistaPd instance");
		try {
			VistaPd result = (VistaPd) getSession().merge(detachedInstance);
			log.debug("merge successful");
			return result;
		} catch (RuntimeException re) {
			log.error("merge failed", re);
			throw re;
		}
	}

	public void attachDirty(VistaPd instance) {
		log.debug("attaching dirty VistaPd instance");
		try {
			getSession().saveOrUpdate(instance);
			log.debug("attach successful");
		} catch (RuntimeException re) {
			log.error("attach failed", re);
			throw re;
		}
	}

	public void attachClean(VistaPd instance) {
		log.debug("attaching clean VistaPd instance");
		try {
			getSession().lock(instance, LockMode.NONE);
			log.debug("attach successful");
		} catch (RuntimeException re) {
			log.error("attach failed", re);
			throw re;
		}
	}
}