
package util;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;


public final class Validaciones {

	private static final Log log = LogFactory.getLog(Validaciones.class);
	private static final String SEPARADOR_FECHA = "/";
	private static final String SEPARADOR_HORA = ":";


	public static boolean esFechaValida(String strfecha) {

		boolean bReturn = false;

		try {

			if (strfecha == null || strfecha.trim() == "") {
				return false;
			}

			String aux[] = strfecha.split(SEPARADOR_FECHA);

			if (aux.length != 3)
				return bReturn;

			if (Integer.parseInt(aux[0]) == 0 || Integer.parseInt(aux[0]) > 31)
				return bReturn;

			if (Integer.parseInt(aux[1]) == 0 || Integer.parseInt(aux[1]) > 12)
				return bReturn;

			if (Integer.parseInt(aux[2]) > 9999)
				return bReturn;


			try {

				if ((strfecha != null) && (!strfecha.equals(""))) {

					bReturn = isValidDate(strfecha);

				} else {

					return false;

				}

			} catch (Exception e) {

				return false;

			}

		} catch (Exception e) {
			log.error(e);
			e.printStackTrace();
		}

		return bReturn;

	}

	public static boolean isValidDate(String inDate) {

		if (inDate == null) {
			return false;
		}

		SimpleDateFormat dateFormat = new SimpleDateFormat("dd/MM/yyyy");

		if (inDate.trim().length() != dateFormat.toPattern().length()) {
			return false;
		}

		dateFormat.setLenient(false);

		try {
			dateFormat.parse(inDate.trim());
		} catch (ParseException e) {
			e.printStackTrace();
			return false;
		}

		return true;

	}


	public static boolean esNumerico(String str) {
		try {
			Integer.parseInt(str);
			return true;
		} catch (NumberFormatException nfe) {
			return false;
		}
	}

	public static boolean esDouble(String str) {
		try {
			Double.parseDouble(str);
			return true;
		} catch (NumberFormatException nfe) {
			return false;
		}
	}

	public static boolean esHoraValida(String strHora) {
		boolean bReturn = false;
		try {
			if (strHora == null || strHora.trim() == "")
				return false;
			String aux[] = strHora.split(SEPARADOR_HORA);
			if (aux.length < 2)
				return bReturn;
			if ((Integer.parseInt(aux[0]) < 0) || Integer.parseInt(aux[0]) > 23)
				return bReturn;
			if ((Integer.parseInt(aux[1]) < 0)
					|| (Integer.parseInt(aux[1]) > 59))
				return bReturn;
			// Hora formato hh:mm:ss
			if (aux.length == 3) {
				if ((Integer.parseInt(aux[2]) < 0)
						|| (Integer.parseInt(aux[2]) > 59))
					return bReturn;
			}
			bReturn = true;
		} catch (Exception e) {
			log.error(e);
			e.printStackTrace();
		}
		return bReturn;
	}


	public static boolean esEmailValido(String correo) {

		return MailValidator.validarCorreoElectronico(correo);
	}

	public static boolean esTlfValido() {
		return true;
	}


	public static boolean esDniValido(String nif) {

		// si es NIE, eliminar la x inicial para tratarlo como nif
		if (nif.startsWith("x") || nif.startsWith("X"))
			nif = nif.substring(1);

		Pattern nifPattern = Pattern
				.compile("(\\d{1,8})([TRWAGMYFPDXBNJZSQVHLCKEtrwagmyfpdxbnjzsqvhlcke])");
		Matcher m = nifPattern.matcher(nif);
		if (m.matches()) {
			String letra = m.group(2);
			// Extraer letra del NIF
			String letras = "TRWAGMYFPDXBNJZSQVHLCKE";
			int dni = Integer.parseInt(m.group(1));
			dni = dni % 23;
			String reference = letras.substring(dni, dni + 1);

			if (reference.equalsIgnoreCase(letra)) {

				return true;
			} else {

				return false;
			}
		} else
			return false;
	}


	public static boolean esTLFValido(String tlf) {

		try {
			Long num = Long.valueOf(tlf);// string-integer
			long numero = num.longValue();// integer-int
			if ((tlf.length() > 50) || (tlf.length() < 9))
				return false;
		} catch (Exception e) {
			return false;
		}
		return true;
	}


	public static boolean esCPValido(String cp) {

		try {
			Integer num = Integer.valueOf(cp);// string-integer
			int numero = num.intValue();// integer-int
			if (cp.length() != 5)
				return false;
		} catch (Exception e) {
			return false;
		}
		return true;
	} 

	public static String libreCaracteresEspeciales(String cadena) {

		// Array de los caracteres especiales
		String[] caracteres = { "'", "\\\\", "/table", "<", ">", "</", "*", "?" };

		try {
			// caracteres
			for (int i = 0; i < caracteres.length; i++) {
				// Si el caracter esta en la cadena
				if (cadena.indexOf(caracteres[i]) >= 0) {
					return caracteres[i];
				}
			}
			return null;

		} catch (Exception e) {
			e.printStackTrace();
			return null;
		}
	}
}
